# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`gitea`](#gitea): main class includes all other classes

#### Private Classes

* `gitea::config`: manages configuration files
* `gitea::install`: download and install gitea
* `gitea::service`: manage service state
* `gitea::user`: creates gitea user

### Defined types

* [`gitea::custom::file`](#giteacustomfile): gitea custom file

## Classes

### <a name="gitea"></a>`gitea`

Install Gitea, a painless self-hosted Git service.
Review module hiera for default parameter values.

* **See also**
  * https://gitea.io

#### Examples

##### Basic usage

```puppet
include gitea
```

##### Install specific version

```puppet
class { 'gitea':
  version  => '1.17.0',
  checksum => 'bc4a8e1f5d5f64d4be2e50c387de08d07c062aecdba2f742c2f61c20accfcc46',
}
```

#### Parameters

The following parameters are available in the `gitea` class:

* [`manage_user`](#manage_user)
* [`manage_group`](#manage_group)
* [`manage_home`](#manage_home)
* [`owner`](#owner)
* [`group`](#group)
* [`home`](#home)
* [`proxy`](#proxy)
* [`base_url`](#base_url)
* [`version`](#version)
* [`checksum`](#checksum)
* [`work_path`](#work_path)
* [`default_configuration`](#default_configuration)
* [`custom_configuration`](#custom_configuration)
* [`manage_service`](#manage_service)
* [`service_epp`](#service_epp)
* [`tmpfile_epp`](#tmpfile_epp)
* [`robots_txt`](#robots_txt)
* [`run_path`](#run_path)

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Should we manage provisioning the user?

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Should we manage provisioning the group?

##### <a name="manage_home"></a>`manage_home`

Data type: `Boolean`

Should we manage provisioning the home directory?

##### <a name="owner"></a>`owner`

Data type: `String`

The user owning gitea

##### <a name="group"></a>`group`

Data type: `String`

The group owning gitea

##### <a name="home"></a>`home`

Data type: `Optional[String]`

Qualified path to the user home directory

##### <a name="proxy"></a>`proxy`

Data type: `Optional[String]`

Download gitea release via specified proxy

##### <a name="base_url"></a>`base_url`

Data type: `String`

Download base URL

##### <a name="version"></a>`version`

Data type: `String`

Version of gitea to install

##### <a name="checksum"></a>`checksum`

Data type: `Optional[Variant[String,Hash]]`

Checksum for the release binary

##### <a name="work_path"></a>`work_path`

Data type: `String`

Target directory for the gitea installation

##### <a name="default_configuration"></a>`default_configuration`

Data type: `Hash`

Settings for configuring Gitea. A simple working configuration is
provided (see hiera). Generally this parameter should NOT be provided.
Instead set the custom_configuration parameter to override built-in
defaults.

##### <a name="custom_configuration"></a>`custom_configuration`

Data type: `Hash`

Override default configuration for configuring Gitea.
The value is merged with the `default_configuration` parameter value.

##### <a name="manage_service"></a>`manage_service`

Data type: `Boolean`

Should we manage a service definition for Gitea?

##### <a name="service_epp"></a>`service_epp`

Data type: `String`

Path to service epp template file

##### <a name="tmpfile_epp"></a>`tmpfile_epp`

Data type: `String`

Path to tmpfile epp template file

##### <a name="robots_txt"></a>`robots_txt`

Data type: `String`

Allows to provide a http://www.robotstxt.org/ file to restrict crawling

##### <a name="run_path"></a>`run_path`

Data type: `String`

Path to service runtime path

## Defined types

### <a name="giteacustomfile"></a>`gitea::custom::file`

Manage files in the Gitea `CustomPath` folder

* **See also**
  * https://docs.gitea.io/en-us/customizing-gitea/

#### Examples

##### custom css

```puppet
gitea::custom::file { 'public/css/custom.css':
  content => file('profile/gitea/custom.css'),
}
```

##### custom logo

```puppet
gitea::custom::file { 'public/img/logo.svg':
  source => 'puppet:///modules/profile/gitea/logo.svg',
}
```

#### Parameters

The following parameters are available in the `gitea::custom::file` defined type:

* [`source`](#source)
* [`content`](#content)

##### <a name="source"></a>`source`

Data type: `Variant[String,Undef]`

File source

Default value: ``undef``

##### <a name="content"></a>`content`

Data type: `Variant[String,Undef]`

File content

Default value: ``undef``

